@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 /***************************************************************************
 Name                 : DB Manager
@@ -19,8 +17,6 @@ email                : brush.tyler@gmail.com
  *                                                                         *
  ***************************************************************************/
 """
-from builtins import str
-from builtins import range
 
 from functools import partial
 from qgis.PyQt.QtCore import Qt, QObject, qDebug, QByteArray, QMimeData, QDataStream, QIODevice, QFileInfo, QAbstractItemModel, QModelIndex, pyqtSignal
@@ -49,6 +45,7 @@ from . import resources_rc  # NOQA
 
 try:
     from qgis.core import QgsVectorLayerExporter  # NOQA
+
     isImportVectorAvail = True
 except:
     isImportVectorAvail = False
