@@ -24,7 +24,6 @@
 #include "qgis_sip.h"
 #include "qgsvector3d.h"
 #include "qgspointcloudattribute.h"
-#include "qgselevationmap.h"
 
 class QgsPointCloudBlock;
 class QgsLayerTreeLayer;
@@ -175,24 +174,6 @@ class CORE_EXPORT QgsPointCloudRenderContext
      */
     QgsFeedback *feedback() const { return mFeedback; }
 
-#ifndef SIP_RUN   // intentionally left out from SIP to avoid API breaks in future when we move elevation post-processing elsewhere
-
-    /**
-     * Sets elevation map that will be used to record elevation of rendered points.
-     * \note Takes ownership of the passed object
-     *
-     * \since QGIS 3.28
-     */
-    void setElevationMap( QgsElevationMap *elevationMap SIP_TRANSFER );
-
-    /**
-     * Returns elevation map. It may be a null pointer if elevation map is not needed in rendering.
-     *
-     * \since QGIS 3.28
-     */
-    QgsElevationMap *elevationMap() { return mElevationMap.get(); }
-#endif
-
 #ifndef SIP_RUN
 
     /**
@@ -260,7 +241,6 @@ class CORE_EXPORT QgsPointCloudRenderContext
     int mZOffset = 0;
     double mZValueScale = 1.0;
     double mZValueFixedOffset = 0;
-    std::unique_ptr<QgsElevationMap> mElevationMap;
 
     QgsFeedback *mFeedback = nullptr;
 };
@@ -485,7 +465,7 @@ class CORE_EXPORT QgsPointCloudRenderer
      * \see pointSizeUnit()
      * \see setPointSizeMapUnitScale()
      */
-    void setPointSizeUnit( const QgsUnitTypes::RenderUnit units ) { mPointSizeUnit = units; }
+    void setPointSizeUnit( const Qgis::RenderUnit units ) { mPointSizeUnit = units; }
 
     /**
      * Returns the units used for the point size.
@@ -493,7 +473,7 @@ class CORE_EXPORT QgsPointCloudRenderer
      * \see pointSize()
      * \see pointSizeMapUnitScale()
      */
-    QgsUnitTypes::RenderUnit pointSizeUnit() const { return mPointSizeUnit; }
+    Qgis::RenderUnit pointSizeUnit() const { return mPointSizeUnit; }
 
     /**
      * Sets the map unit \a scale used for the point size.
@@ -571,7 +551,7 @@ class CORE_EXPORT QgsPointCloudRenderer
      * \see maximumScreenError()
      * \see setMaximumScreenErrorUnit()
      */
-    QgsUnitTypes::RenderUnit maximumScreenErrorUnit() const;
+    Qgis::RenderUnit maximumScreenErrorUnit() const;
 
     /**
      * Sets the \a unit for the maximum screen error allowed when rendering the point cloud.
@@ -579,7 +559,7 @@ class CORE_EXPORT QgsPointCloudRenderer
      * \see setMaximumScreenError()
      * \see maximumScreenErrorUnit()
      */
-    void setMaximumScreenErrorUnit( QgsUnitTypes::RenderUnit unit );
+    void setMaximumScreenErrorUnit( Qgis::RenderUnit unit );
 
     /**
      * Creates a set of legend nodes representing the renderer.
@@ -591,62 +571,6 @@ class CORE_EXPORT QgsPointCloudRenderer
      */
     virtual QStringList legendRuleKeys() const;
 
-    /**
-     * Returns whether eye dome lighting effect will be used
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    bool eyeDomeLightingEnabled() const { return mEyeDomeLightingEnabled; }
-
-    /**
-     * Sets whether eye dome lighting effect will be used
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    void setEyeDomeLightingEnabled( bool enabled ) { mEyeDomeLightingEnabled = enabled; }
-
-    /**
-     * Returns the eye dome lighting strength value
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    double eyeDomeLightingStrength() const { return mEyeDomeLightingStrength; }
-
-    /**
-     * Sets the eye dome lighting strength value
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    void setEyeDomeLightingStrength( double strength ) { mEyeDomeLightingStrength = strength; }
-
-    /**
-     * Returns the eye dome lighting distance
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    double eyeDomeLightingDistance() const { return mEyeDomeLightingDistance; }
-
-    /**
-     * Sets the eye dome lighting distance
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    void setEyeDomeLightingDistance( double distance ) { mEyeDomeLightingDistance = distance; }
-
-    /**
-     * Returns unit for the eye dome lighting distance
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    QgsUnitTypes::RenderUnit eyeDomeLightingDistanceUnit() const { return mEyeDomeLightingDistanceUnit; }
-
-    /**
-     * Sets unit for the eye dome lighting distance
-     * \note This is not a part of stable API - this function may be removed in a future release
-     * \since QGIS 3.28
-     */
-    void setEyeDomeLightingDistanceUnit( QgsUnitTypes::RenderUnit unit ) { mEyeDomeLightingDistanceUnit = unit; }
-
   protected:
 
     /**
@@ -740,20 +664,15 @@ class CORE_EXPORT QgsPointCloudRenderer
 #endif
 
     double mMaximumScreenError = 0.3;
-    QgsUnitTypes::RenderUnit mMaximumScreenErrorUnit = QgsUnitTypes::RenderMillimeters;
+    Qgis::RenderUnit mMaximumScreenErrorUnit = Qgis::RenderUnit::Millimeters;
 
     double mPointSize = 1;
-    QgsUnitTypes::RenderUnit mPointSizeUnit = QgsUnitTypes::RenderMillimeters;
+    Qgis::RenderUnit mPointSizeUnit = Qgis::RenderUnit::Millimeters;
     QgsMapUnitScale mPointSizeMapUnitScale;
 
     Qgis::PointCloudSymbol mPointSymbol = Qgis::PointCloudSymbol::Square;
     int mPainterPenWidth = 1;
     Qgis::PointCloudDrawOrder mDrawOrder2d = Qgis::PointCloudDrawOrder::Default;
-
-    bool mEyeDomeLightingEnabled = false;
-    double mEyeDomeLightingStrength = 1000.0;
-    double mEyeDomeLightingDistance = 0.5;
-    QgsUnitTypes::RenderUnit mEyeDomeLightingDistanceUnit = QgsUnitTypes::RenderMillimeters;
 };
 
 #endif // QGSPOINTCLOUDRENDERER_H
