@@ -28,6 +28,7 @@
 #include "qgsexception.h"
 #include "qgsprojoperation.h"
 
+#include <QFileInfo>
 #include <sqlite3.h>
 #include <mutex>
 #include <proj.h>
@@ -50,7 +51,7 @@ QList<QgsCoordinateReferenceSystemRegistry::UserCrsDetails> QgsCoordinateReferen
   int result = database.open_v2( QgsApplication::qgisUserDatabaseFilePath(), SQLITE_OPEN_READONLY, nullptr );
   if ( result != SQLITE_OK )
   {
-    QgsDebugMsg( QStringLiteral( "Can't open database: %1" ).arg( database.errorMessage() ) );
+    QgsDebugError( QStringLiteral( "Can't open database: %1" ).arg( database.errorMessage() ) );
     return res;
   }
 
@@ -79,7 +80,7 @@ QList<QgsCoordinateReferenceSystemRegistry::UserCrsDetails> QgsCoordinateReferen
   return res;
 }
 
-long QgsCoordinateReferenceSystemRegistry::addUserCrs( const QgsCoordinateReferenceSystem &crs, const QString &name, QgsCoordinateReferenceSystem::Format nativeFormat )
+long QgsCoordinateReferenceSystemRegistry::addUserCrs( const QgsCoordinateReferenceSystem &crs, const QString &name, Qgis::CrsDefinitionFormat nativeFormat )
 {
   if ( !crs.isValid() )
   {
@@ -113,7 +114,7 @@ long QgsCoordinateReferenceSystemRegistry::addUserCrs( const QgsCoordinateRefere
             + ',' + quotedEllipsoidString
             + ',' + ( !proj4String.isEmpty() ? QgsSqliteUtils::quotedString( proj4String ) : QStringLiteral( "''" ) )
             + ",0,"  // <-- is_geo shamelessly hard coded for now
-            + ( nativeFormat == QgsCoordinateReferenceSystem::FormatWkt ? QgsSqliteUtils::quotedString( wktString ) : QStringLiteral( "''" ) )
+            + ( nativeFormat == Qgis::CrsDefinitionFormat::Wkt ? QgsSqliteUtils::quotedString( wktString ) : QStringLiteral( "''" ) )
             + ')';
   }
   else
@@ -124,7 +125,7 @@ long QgsCoordinateReferenceSystemRegistry::addUserCrs( const QgsCoordinateRefere
             + ',' + quotedEllipsoidString
             + ',' + ( !proj4String.isEmpty() ? QgsSqliteUtils::quotedString( proj4String ) : QStringLiteral( "''" ) )
             + ",0,"  // <-- is_geo shamelessly hard coded for now
-            + ( nativeFormat == QgsCoordinateReferenceSystem::FormatWkt ? QgsSqliteUtils::quotedString( wktString ) : QStringLiteral( "''" ) )
+            + ( nativeFormat == Qgis::CrsDefinitionFormat::Wkt ? QgsSqliteUtils::quotedString( wktString ) : QStringLiteral( "''" ) )
             + ')';
   }
   sqlite3_database_unique_ptr database;
@@ -133,9 +134,9 @@ long QgsCoordinateReferenceSystemRegistry::addUserCrs( const QgsCoordinateRefere
   int myResult = database.open( QgsApplication::qgisUserDatabaseFilePath() );
   if ( myResult != SQLITE_OK )
   {
-    QgsDebugMsg( QStringLiteral( "Can't open or create database %1: %2" )
-                 .arg( QgsApplication::qgisUserDatabaseFilePath(),
-                       database.errorMessage() ) );
+    QgsDebugError( QStringLiteral( "Can't open or create database %1: %2" )
+                   .arg( QgsApplication::qgisUserDatabaseFilePath(),
+                         database.errorMessage() ) );
     return false;
   }
   statement = database.prepare( mySql, myResult );
@@ -171,7 +172,7 @@ long QgsCoordinateReferenceSystemRegistry::addUserCrs( const QgsCoordinateRefere
   return returnId;
 }
 
-bool QgsCoordinateReferenceSystemRegistry::updateUserCrs( long id, const QgsCoordinateReferenceSystem &crs, const QString &name, QgsCoordinateReferenceSystem::Format nativeFormat )
+bool QgsCoordinateReferenceSystemRegistry::updateUserCrs( long id, const QgsCoordinateReferenceSystem &crs, const QString &name, Qgis::CrsDefinitionFormat nativeFormat )
 {
   if ( !crs.isValid() )
   {
@@ -185,7 +186,7 @@ bool QgsCoordinateReferenceSystemRegistry::updateUserCrs( long id, const QgsCoor
                       + ",ellipsoid_acronym=" + ( !crs.ellipsoidAcronym().isEmpty() ? QgsSqliteUtils::quotedString( crs.ellipsoidAcronym() ) : QStringLiteral( "''" ) )
                       + ",parameters=" + ( !crs.toProj().isEmpty() ? QgsSqliteUtils::quotedString( crs.toProj() ) : QStringLiteral( "''" ) )
                       + ",is_geo=0" // <--shamelessly hard coded for now
-                      + ",wkt=" + ( nativeFormat == QgsCoordinateReferenceSystem::FormatWkt ? QgsSqliteUtils::quotedString( crs.toWkt( QgsCoordinateReferenceSystem::WKT_PREFERRED, false ) ) : QStringLiteral( "''" ) )
+                      + ",wkt=" + ( nativeFormat == Qgis::CrsDefinitionFormat::Wkt ? QgsSqliteUtils::quotedString( crs.toWkt( QgsCoordinateReferenceSystem::WKT_PREFERRED, false ) ) : QStringLiteral( "''" ) )
                       + " where srs_id=" + QgsSqliteUtils::quotedString( QString::number( id ) )
                       ;
 
@@ -194,9 +195,9 @@ bool QgsCoordinateReferenceSystemRegistry::updateUserCrs( long id, const QgsCoor
   const int myResult = database.open( QgsApplication::qgisUserDatabaseFilePath() );
   if ( myResult != SQLITE_OK )
   {
-    QgsDebugMsg( QStringLiteral( "Can't open or create database %1: %2" )
-                 .arg( QgsApplication::qgisUserDatabaseFilePath(),
-                       database.errorMessage() ) );
+    QgsDebugError( QStringLiteral( "Can't open or create database %1: %2" )
+                   .arg( QgsApplication::qgisUserDatabaseFilePath(),
+                         database.errorMessage() ) );
     return false;
   }
 
@@ -234,7 +235,7 @@ bool QgsCoordinateReferenceSystemRegistry::updateUserCrs( long id, const QgsCoor
 
   if ( res )
   {
-    emit userCrsChanged( crs.d->mAuthId );
+    emit userCrsChanged( QStringLiteral( "USER:%1" ).arg( id ) );
     emit crsDefinitionsChanged();
   }
 
@@ -251,8 +252,8 @@ bool QgsCoordinateReferenceSystemRegistry::removeUserCrs( long id )
   int result = database.open( QgsApplication::qgisUserDatabaseFilePath() );
   if ( result != SQLITE_OK )
   {
-    QgsDebugMsg( QStringLiteral( "Can't open database: %1 \n please notify QGIS developers of this error \n %2 (file name) " ).arg( database.errorMessage(),
-                 QgsApplication::qgisUserDatabaseFilePath() ) );
+    QgsDebugError( QStringLiteral( "Can't open database: %1 \n please notify QGIS developers of this error \n %2 (file name) " ).arg( database.errorMessage(),
+                   QgsApplication::qgisUserDatabaseFilePath() ) );
     return false;
   }
 
@@ -261,7 +262,7 @@ bool QgsCoordinateReferenceSystemRegistry::removeUserCrs( long id )
     sqlite3_statement_unique_ptr preparedStatement = database.prepare( sql, result );
     if ( result != SQLITE_OK || preparedStatement.step() != SQLITE_DONE )
     {
-      QgsDebugMsg( QStringLiteral( "failed to remove custom CRS from database: %1 [%2]" ).arg( sql, database.errorMessage() ) );
+      QgsDebugError( QStringLiteral( "failed to remove custom CRS from database: %1 [%2]" ).arg( sql, database.errorMessage() ) );
       res = false;
     }
     else
@@ -301,15 +302,15 @@ bool QgsCoordinateReferenceSystemRegistry::insertProjection( const QString &proj
   int result = database.open( QgsApplication::qgisUserDatabaseFilePath() );
   if ( result != SQLITE_OK )
   {
-    QgsDebugMsg( QStringLiteral( "Can't open database: %1 \n please notify  QGIS developers of this error \n %2 (file name) " ).arg( database.errorMessage(),
-                 QgsApplication::qgisUserDatabaseFilePath() ) );
+    QgsDebugError( QStringLiteral( "Can't open database: %1 \n please notify  QGIS developers of this error \n %2 (file name) " ).arg( database.errorMessage(),
+                   QgsApplication::qgisUserDatabaseFilePath() ) );
     return false;
   }
   int srsResult = srsDatabase.open( QgsApplication::srsDatabaseFilePath() );
   if ( result != SQLITE_OK )
   {
-    QgsDebugMsg( QStringLiteral( "Can't open database %1 [%2]" ).arg( QgsApplication::srsDatabaseFilePath(),
-                 srsDatabase.errorMessage() ) );
+    QgsDebugError( QStringLiteral( "Can't open database %1 [%2]" ).arg( QgsApplication::srsDatabaseFilePath(),
+                   srsDatabase.errorMessage() ) );
     return false;
   }
 
@@ -332,14 +333,14 @@ bool QgsCoordinateReferenceSystemRegistry::insertProjection( const QString &proj
       sqlite3_statement_unique_ptr preparedStatement = database.prepare( sql, result );
       if ( result != SQLITE_OK || preparedStatement.step() != SQLITE_DONE )
       {
-        QgsDebugMsg( QStringLiteral( "Could not insert projection into database: %1 [%2]" ).arg( sql, database.errorMessage() ) );
+        QgsDebugError( QStringLiteral( "Could not insert projection into database: %1 [%2]" ).arg( sql, database.errorMessage() ) );
         return false;
       }
     }
   }
   else
   {
-    QgsDebugMsg( QStringLiteral( "prepare failed: %1 [%2]" ).arg( srsSql, srsDatabase.errorMessage() ) );
+    QgsDebugError( QStringLiteral( "prepare failed: %1 [%2]" ).arg( srsSql, srsDatabase.errorMessage() ) );
     return false;
   }
 
@@ -409,3 +410,62 @@ QList< QgsCelestialBody> QgsCoordinateReferenceSystemRegistry::celestialBodies()
   throw QgsNotSupportedException( QObject::tr( "Retrieving celestial bodies requires a QGIS build based on PROJ 8.1 or later" ) );
 #endif
 }
+
+QSet<QString> QgsCoordinateReferenceSystemRegistry::authorities() const
+{
+  static std::once_flag initialized;
+  std::call_once( initialized, [ = ]
+  {
+    QgsScopedRuntimeProfile profile( QObject::tr( "Initialize authorities" ) );
+
+    PJ_CONTEXT *pjContext = QgsProjContext::get();
+    PROJ_STRING_LIST authorities = proj_get_authorities_from_database( pjContext );
+
+    for ( auto authIter = authorities; authIter && *authIter; ++authIter )
+    {
+      const QString authority( *authIter );
+      mKnownAuthorities.insert( authority.toLower() );
+    }
+
+    proj_string_list_destroy( authorities );
+  } );
+
+  return mKnownAuthorities;
+}
+
+QList<QgsCrsDbRecord> QgsCoordinateReferenceSystemRegistry::crsDbRecords() const
+{
+  static std::once_flag initialized;
+  std::call_once( initialized, [ = ]
+  {
+    const QString srsDatabaseFileName = QgsApplication::srsDatabaseFilePath();
+    if ( QFileInfo::exists( srsDatabaseFileName ) )
+    {
+      // open the database containing the spatial reference data, and do a one-time read
+      sqlite3_database_unique_ptr database;
+      int result = database.open_v2( srsDatabaseFileName, SQLITE_OPEN_READONLY, nullptr );
+      if ( result == SQLITE_OK )
+      {
+        const QString sql = QStringLiteral( "SELECT description, srs_id, auth_name, auth_id, projection_acronym, deprecated, srs_type FROM tbl_srs" );
+        sqlite3_statement_unique_ptr preparedStatement = database.prepare( sql, result );
+        if ( result == SQLITE_OK )
+        {
+          while ( preparedStatement.step() == SQLITE_ROW )
+          {
+            QgsCrsDbRecord record;
+            record.description = preparedStatement.columnAsText( 0 );
+            record.srsId = preparedStatement.columnAsText( 1 );
+            record.authName = preparedStatement.columnAsText( 2 );
+            record.authId = preparedStatement.columnAsText( 3 );
+            record.projectionAcronym = preparedStatement.columnAsText( 4 );
+            record.deprecated = preparedStatement.columnAsText( 5 ).toInt();
+            record.type = qgsEnumKeyToValue( preparedStatement.columnAsText( 6 ), Qgis::CrsType::Unknown );
+            mCrsDbRecords.append( record );
+          }
+        }
+      }
+    }
+  } );
+
+  return mCrsDbRecords;
+}
