@@ -44,7 +44,7 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     static Qgis::VectorExportResult createEmptyLayer(
       const QString &uri,
       const QgsFields &fields,
-      QgsWkbTypes::Type wkbType,
+      Qgis::WkbType wkbType,
       const QgsCoordinateReferenceSystem &srs,
       bool overwrite,
       QMap<int, int> *oldToNewAttrIdxMap,
@@ -91,7 +91,7 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     QString subsetString() const override;
     bool supportsSubsetString() const override { return true; }
     bool setSubsetString( const QString &theSQL, bool updateFeatureCount = true ) override;
-    QgsWkbTypes::Type wkbType() const override;
+    Qgis::WkbType wkbType() const override;
     virtual size_t layerCount() const;
     long long featureCount() const override;
     QgsFields fields() const override;
@@ -110,12 +110,12 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     bool createSpatialIndex() override;
     bool createAttributeIndex( int field ) override;
     QgsVectorDataProvider::Capabilities capabilities() const override;
+    Qgis::VectorDataProviderAttributeEditCapabilities attributeEditCapabilities() const override;
     QgsAttributeList pkAttributeIndexes() const override { return mPrimaryKeyAttrs; }
     void setEncoding( const QString &e ) override;
     bool enterUpdateMode() override { return _enterUpdateMode(); }
     bool leaveUpdateMode() override;
-    bool isSaveAndLoadStyleToDatabaseSupported() const override;
-    bool isDeleteStyleFromDatabaseSupported() const override;
+    Qgis::ProviderStyleStorageCapabilities styleStorageCapabilities() const override;
     QString fileVectorFilters() const override;
     bool isValid() const override;
     QVariant minimumValue( int index ) const override;
@@ -124,6 +124,8 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     QStringList uniqueStringsMatching( int index, const QString &substring, int limit = -1,
                                        QgsFeedback *feedback = nullptr ) const override;
     QgsFeatureSource::SpatialIndexPresence hasSpatialIndex() const override;
+    Qgis::VectorLayerTypeFlags vectorLayerTypeFlags() const override;
+    QList<QgsRelation> discoverRelations( const QgsVectorLayer *target, const QList<QgsVectorLayer *> &layers ) const override;
 
     QString name() const override;
     static QString providerKey();
@@ -198,6 +200,8 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     //! Does the real job of settings the subset string and adds an argument to disable update capabilities
     bool _setSubsetString( const QString &theSQL, bool updateFeatureCount = true, bool updateCapabilities = true, bool hasExistingRef = true );
 
+    bool  createSpatialIndexImpl();
+
     QList< QgsProviderSublayerDetails > _subLayers( Qgis::SublayerQueryFlags flags ) const;
 
     QgsFields mAttributeFields;
@@ -256,6 +260,16 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     */
     OGRwkbGeometryType mOgrGeometryTypeFilter = wkbUnknown;
 
+    /**
+     * This flag is only used when mOgrGeometryTypeFilter != wkbUnknown.
+     * When it is set, it indicates that the layer actually contains only
+     * geometries of the type specified by mOgrGeometryTypeFilter (and potentially
+     * null geometries as well). In that situation, filtering on the geometry
+     * type is not actually needed, which enables to use the fast implementation
+     * of getFeatureCount().
+     */
+    bool mUniqueGeometryType = false;
+
     //! current spatial filter
     QgsRectangle mFetchRect;
 
@@ -314,6 +328,7 @@ class QgsOgrProvider final: public QgsVectorDataProvider
     void computeCapabilities();
 
     QgsVectorDataProvider::Capabilities mCapabilities = QgsVectorDataProvider::Capabilities();
+    Qgis::VectorDataProviderAttributeEditCapabilities mAttributeEditCapabilities = Qgis::VectorDataProviderAttributeEditCapabilities();
 
     bool doInitialActionsForEdition();
 
@@ -332,6 +347,8 @@ class QgsOgrProvider final: public QgsVectorDataProvider
 
     //! Invalidate GDAL /vsicurl/ RAM cache for mFilePath
     void invalidateNetworkCache();
+
+    bool mShapefileHadSpatialIndex = false;
 };
 
 ///@endcond
