@@ -16,10 +16,10 @@ email                : jef at norbit dot de
 #include "qgis.h"
 #include "qgsgeometryvalidator.h"
 #include "qgsgeometry.h"
+#include "qgsgeometryutils.h"
 #include "qgslogger.h"
 #include "qgsgeos.h"
 #include "qgsgeometrycollection.h"
-#include "qgspolygon.h"
 #include "qgscurvepolygon.h"
 #include "qgscurve.h"
 #include "qgsvertexid.h"
@@ -188,59 +188,21 @@ void QgsGeometryValidator::validatePolyline( int i, const QgsLineString *line, b
     line = noDupes.get();
   }
 
+  // segment Intersection
   for ( int j = 0; !mStop && j < line->numPoints() - 3; j++ )
   {
-    const double xAtJ = line->xAt( j );
-    const double yAtJ = line->yAt( j );
-    const QgsVector v( line->xAt( j + 1 ) - xAtJ, line->yAt( j + 1 ) - yAtJ );
-    const double vl = v.length();
-
     const int n = ( j == 0 && ring ) ? line->numPoints() - 2 : line->numPoints() - 1;
-
     for ( int k = j + 2; !mStop && k < n; k++ )
     {
-      const double xAtK = line->xAt( k );
-      const double yAtK = line->yAt( k );
-
-      const QgsVector w( line->xAt( k + 1 ) - xAtK, line->yAt( k + 1 ) - yAtK );
-
-      double sX;
-      double sY;
-      if ( !intersectLines( xAtJ, yAtJ, v, xAtK, yAtK, w, sX, sY ) )
-        continue;
-
-      double d = 0.0;
-      try
+      QgsPoint intersectionPoint;
+      bool isIntersection = false;
+      if ( QgsGeometryUtils::segmentIntersection( line->pointN( j ), line->pointN( j + 1 ), line->pointN( k ), line->pointN( k + 1 ), intersectionPoint, isIntersection ) )
       {
-        d = -distLine2Point( xAtJ, yAtJ, v.perpVector(), sX, sY );
+        const QString msg = QObject::tr( "segments %1 and %2 of line %3 intersect at %4, %5" ).arg( j ).arg( k ).arg( i ).arg( intersectionPoint.x() ).arg( intersectionPoint.y() );
+        QgsDebugMsgLevel( msg, 2 );
+        emit errorFound( QgsGeometry::Error( msg, QgsPointXY( intersectionPoint.x(), intersectionPoint.y() ) ) );
+        mErrorCount++;
       }
-      catch ( QgsException &e )
-      {
-        Q_UNUSED( e )
-        QgsDebugMsg( "Error validating: " + e.what() );
-        continue;
-      }
-      if ( d < 0 || d > vl )
-        continue;
-
-      try
-      {
-        d = -distLine2Point( xAtK, yAtK, w.perpVector(), sX, sY );
-      }
-      catch ( QgsException &e )
-      {
-        Q_UNUSED( e )
-        QgsDebugMsg( "Error validating: " + e.what() );
-        continue;
-      }
-
-      if ( d <= 0 || d >= w.length() )
-        continue;
-
-      const QString msg = QObject::tr( "segments %1 and %2 of line %3 intersect at %4, %5" ).arg( j ).arg( k ).arg( i ).arg( sX ).arg( sY );
-      QgsDebugMsgLevel( msg, 2 );
-      emit errorFound( QgsGeometry::Error( msg, QgsPointXY( sX, sY ) ) );
-      mErrorCount++;
     }
   }
 }
@@ -253,7 +215,7 @@ void QgsGeometryValidator::validatePolygon( int partIndex, const QgsCurvePolygon
     if ( !ringInRing( polygon->interiorRing( i ), polygon->exteriorRing() ) )
     {
       const QString msg = QObject::tr( "ring %1 of polygon %2 not in exterior ring" ).arg( i + 1 ).arg( partIndex );
-      QgsDebugMsg( msg );
+      QgsDebugMsgLevel( msg, 2 );
       emit errorFound( QgsGeometry::Error( msg ) );
       mErrorCount++;
     }
@@ -290,7 +252,7 @@ void QgsGeometryValidator::run()
     case Qgis::GeometryValidationEngine::Geos:
     {
       // avoid calling geos for trivial point geometries
-      if ( QgsWkbTypes::geometryType( mGeometry.wkbType() ) == QgsWkbTypes::PointGeometry )
+      if ( QgsWkbTypes::geometryType( mGeometry.wkbType() ) == Qgis::GeometryType::Point )
       {
         return;
       }
@@ -320,15 +282,15 @@ void QgsGeometryValidator::run()
     {
       switch ( QgsWkbTypes::flatType( mGeometry.constGet()->wkbType() ) )
       {
-        case QgsWkbTypes::Point:
-        case QgsWkbTypes::MultiPoint:
+        case Qgis::WkbType::Point:
+        case Qgis::WkbType::MultiPoint:
           break;
 
-        case QgsWkbTypes::LineString:
+        case Qgis::WkbType::LineString:
           validatePolyline( 0, qgsgeometry_cast< const QgsLineString * >( mGeometry.constGet() ) );
           break;
 
-        case QgsWkbTypes::MultiLineString:
+        case Qgis::WkbType::MultiLineString:
         {
           const QgsGeometryCollection *collection = qgsgeometry_cast< const QgsGeometryCollection * >( mGeometry.constGet() );
           for ( int i = 0; !mStop && i < collection->numGeometries(); i++ )
@@ -336,13 +298,13 @@ void QgsGeometryValidator::run()
           break;
         }
 
-        case QgsWkbTypes::Polygon:
-        case QgsWkbTypes::CurvePolygon:
+        case Qgis::WkbType::Polygon:
+        case Qgis::WkbType::CurvePolygon:
           validatePolygon( 0, qgsgeometry_cast< const QgsCurvePolygon * >( mGeometry.constGet() ) );
           break;
 
-        case QgsWkbTypes::MultiPolygon:
-        case QgsWkbTypes::MultiSurface:
+        case Qgis::WkbType::MultiPolygon:
+        case Qgis::WkbType::MultiSurface:
         {
           const QgsGeometryCollection *collection = qgsgeometry_cast< const QgsGeometryCollection * >( mGeometry.constGet() );
           for ( int i = 0; !mStop && i < collection->numGeometries(); i++ )
@@ -386,9 +348,9 @@ void QgsGeometryValidator::run()
           break;
         }
 
-        case QgsWkbTypes::Unknown:
+        case Qgis::WkbType::Unknown:
         {
-          emit errorFound( QgsGeometry::Error( QObject::tr( "Unknown geometry type %1" ).arg( mGeometry.wkbType() ) ) );
+          emit errorFound( QgsGeometry::Error( QObject::tr( "Unknown geometry type %1" ).arg( qgsEnumValueToKey( mGeometry.wkbType() ) ) ) );
           mErrorCount++;
           break;
         }
