@@ -195,7 +195,7 @@ QgsStringMap QgsCptCityArchive::copyingInfo( const QString &fileName )
   QFile f( fileName );
   if ( !f.open( QFile::ReadOnly ) )
   {
-    QgsDebugMsg( "Couldn't open xml file: " + fileName );
+    QgsDebugError( "Couldn't open xml file: " + fileName );
     return copyingMap;
   }
 
@@ -204,7 +204,7 @@ QgsStringMap QgsCptCityArchive::copyingInfo( const QString &fileName )
   if ( !doc.setContent( &f ) )
   {
     f.close();
-    QgsDebugMsg( "Couldn't parse xml file: " + fileName );
+    QgsDebugError( "Couldn't parse xml file: " + fileName );
     return copyingMap;
   }
   f.close();
@@ -213,7 +213,7 @@ QgsStringMap QgsCptCityArchive::copyingInfo( const QString &fileName )
   const QDomElement docElem = doc.documentElement();
   if ( docElem.tagName() != QLatin1String( "copying" ) )
   {
-    QgsDebugMsg( "Incorrect root tag: " + docElem.tagName() );
+    QgsDebugError( "Incorrect root tag: " + docElem.tagName() );
     return copyingMap;
   }
 
@@ -296,7 +296,7 @@ QgsStringMap QgsCptCityArchive::description( const QString &fileName )
   if ( !doc.setContent( &f, &errMsg ) )
   {
     f.close();
-    QgsDebugMsg( "Couldn't parse file " + fileName + " : " + errMsg );
+    QgsDebugError( "Couldn't parse file " + fileName + " : " + errMsg );
     return descMap;
   }
   f.close();
@@ -305,7 +305,7 @@ QgsStringMap QgsCptCityArchive::description( const QString &fileName )
   const QDomElement docElem = doc.documentElement();
   if ( docElem.tagName() != QLatin1String( "description" ) )
   {
-    QgsDebugMsg( "Incorrect root tag: " + docElem.tagName() );
+    QgsDebugError( "Incorrect root tag: " + docElem.tagName() );
     return descMap;
   }
   // should we make sure the <dir> tag is OK?
@@ -334,7 +334,7 @@ QMap< double, QPair<QColor, QColor> >QgsCptCityArchive::gradientColorMap( const
   QFile f( fileName );
   if ( !f.open( QFile::ReadOnly ) )
   {
-    QgsDebugMsg( "Couldn't open SVG file: " + fileName );
+    QgsDebugError( "Couldn't open SVG file: " + fileName );
     return colorMap;
   }
 
@@ -343,7 +343,7 @@ QMap< double, QPair<QColor, QColor> >QgsCptCityArchive::gradientColorMap( const
   if ( !doc.setContent( &f ) )
   {
     f.close();
-    QgsDebugMsg( "Couldn't parse SVG file: " + fileName );
+    QgsDebugError( "Couldn't parse SVG file: " + fileName );
     return colorMap;
   }
   f.close();
@@ -352,7 +352,7 @@ QMap< double, QPair<QColor, QColor> >QgsCptCityArchive::gradientColorMap( const
 
   if ( docElem.tagName() != QLatin1String( "svg" ) )
   {
-    QgsDebugMsg( "Incorrect root tag: " + docElem.tagName() );
+    QgsDebugError( "Incorrect root tag: " + docElem.tagName() );
     return colorMap;
   }
 
@@ -366,7 +366,7 @@ QMap< double, QPair<QColor, QColor> >QgsCptCityArchive::gradientColorMap( const
   }
   if ( rampsElement.isNull() )
   {
-    QgsDebugMsg( QStringLiteral( "linearGradient tag missing" ) );
+    QgsDebugError( QStringLiteral( "linearGradient tag missing" ) );
     return colorMap;
   }
 
@@ -409,12 +409,12 @@ QMap< double, QPair<QColor, QColor> >QgsCptCityArchive::gradientColorMap( const
       }
       else
       {
-        QgsDebugMsg( QStringLiteral( "at offset=%1 invalid color \"%2\"" ).arg( offset ).arg( colorStr ) );
+        QgsDebugError( QStringLiteral( "at offset=%1 invalid color \"%2\"" ).arg( offset ).arg( colorStr ) );
       }
     }
     else
     {
-      QgsDebugMsg( "unknown tag: " + e.tagName() );
+      QgsDebugError( "unknown tag: " + e.tagName() );
     }
 
     e = e.nextSiblingElement();
@@ -496,7 +496,7 @@ void QgsCptCityArchive::initArchives( bool loadAll )
       QgsCptCityArchive::initArchive( it.key(), it.value() );
     else
     {
-      QgsDebugMsg( QStringLiteral( "not loading archive [%1] because dir %2 does not exist " ).arg( it.key(), it.value() ) );
+      QgsDebugError( QStringLiteral( "not loading archive [%1] because dir %2 does not exist " ).arg( it.key(), it.value() ) );
     }
   }
   *sDefaultArchiveName() = defArchiveName;
@@ -872,7 +872,7 @@ QVector< QgsCptCityDataItem * > QgsCptCityCollectionItem::childrenRamps( bool re
     }
     else
     {
-      QgsDebugMsg( "invalid item " + childItem->path() );
+      QgsDebugError( "invalid item " + childItem->path() );
     }
   }
 
@@ -880,7 +880,7 @@ QVector< QgsCptCityDataItem * > QgsCptCityCollectionItem::childrenRamps( bool re
   const auto constDeleteItems = deleteItems;
   for ( QgsCptCityDataItem *deleteItem : constDeleteItems )
   {
-    QgsDebugMsg( QStringLiteral( "item %1 is invalid, will be deleted" ).arg( deleteItem->path() ) );
+    QgsDebugError( QStringLiteral( "item %1 is invalid, will be deleted" ).arg( deleteItem->path() ) );
     const int i = mChildren.indexOf( deleteItem );
     if ( i != -1 )
       mChildren.remove( i );
@@ -899,8 +899,8 @@ QgsCptCityDirectoryItem::QgsCptCityDirectoryItem( QgsCptCityDataItem *parent,
   mValid = QDir( QgsCptCityArchive::defaultBaseDir() + '/' + mPath ).exists();
   if ( ! mValid )
   {
-    QgsDebugMsg( "created invalid dir item, path = " + QgsCptCityArchive::defaultBaseDir()
-                 + '/' + mPath );
+    QgsDebugError( "created invalid dir item, path = " + QgsCptCityArchive::defaultBaseDir()
+                   + '/' + mPath );
   }
 
   // parse DESC.xml to get mInfo
@@ -1218,7 +1218,7 @@ void QgsCptCitySelectionItem::parseXml()
   QFile f( filename );
   if ( ! f.open( QFile::ReadOnly ) )
   {
-    QgsDebugMsg( filename + " does not exist" );
+    QgsDebugError( filename + " does not exist" );
     return;
   }
 
@@ -1228,7 +1228,7 @@ void QgsCptCitySelectionItem::parseXml()
   if ( !doc.setContent( &f, &errMsg ) )
   {
     f.close();
-    QgsDebugMsg( "Couldn't parse file " + filename + " : " + errMsg );
+    QgsDebugError( "Couldn't parse file " + filename + " : " + errMsg );
     return;
   }
   f.close();
@@ -1237,7 +1237,7 @@ void QgsCptCitySelectionItem::parseXml()
   const QDomElement docElem = doc.documentElement();
   if ( docElem.tagName() != QLatin1String( "selection" ) )
   {
-    QgsDebugMsg( "Incorrect root tag: " + docElem.tagName() );
+    QgsDebugError( "Incorrect root tag: " + docElem.tagName() );
     return;
   }
   QDomElement e = docElem.firstChildElement( QStringLiteral( "name" ) );
@@ -1727,7 +1727,7 @@ bool QgsCptCityBrowserModel::dropMimeData( const QMimeData *data, Qt::DropAction
   QgsCptCityDataItem *destItem = dataItem( parent );
   if ( !destItem )
   {
-    QgsDebugMsg( QStringLiteral( "DROP PROBLEM!" ) );
+    QgsDebugError( QStringLiteral( "DROP PROBLEM!" ) );
     return false;
   }
 
