@@ -16,7 +16,6 @@
 #ifndef QGSAFSSHAREDDATA_H
 #define QGSAFSSHAREDDATA_H
 
-#include <QObject>
 #include <QMutex>
 #include "qgsfields.h"
 #include "qgsfeature.h"
@@ -29,12 +28,15 @@ class QgsFeedback;
 /**
  * \brief This class holds data, shared between QgsAfsProvider and QgsAfsFeatureIterator
  */
-class QgsAfsSharedData : public QObject
+class QgsAfsSharedData
 {
-    Q_OBJECT
+
   public:
     QgsAfsSharedData( const QgsDataSourceUri &uri );
 
+    //! Creates a deep copy of this shared data
+    std::shared_ptr< QgsAfsSharedData > clone() const;
+
     long long objectIdCount() const;
     long long featureCount() const;
     bool isDeleted( QgsFeatureId id ) const { return mDeletedFeatureIds.contains( id ); }
@@ -75,7 +77,7 @@ class QgsAfsSharedData : public QObject
     QgsDataSourceUri mDataSource;
     bool mLimitBBox = false;
     QgsRectangle mExtent;
-    QgsWkbTypes::Type mGeometryType = QgsWkbTypes::Unknown;
+    Qgis::WkbType mGeometryType = Qgis::WkbType::Unknown;
     QgsFields mFields;
     int mMaximumFetchObjectsCount = 100;
 
