@@ -33,6 +33,7 @@ class QgsTreeWidgetItem;
 class QDomDocument;
 class QDomElement;
 class QgsWmsCapabilities;
+class QgsWmsInterpretationComboBox;
 
 /*!
  * \brief   Dialog to create connections and add layers from WMS, etc.
@@ -128,7 +129,6 @@ class QgsWMSSourceSelect : public QgsAbstractDataSourceWidget, private Ui::QgsWM
     //! Map mime types to supported formats
     QMap<QString, int> mMimeMap;
 
-
     // Clear layers list, crs, encodings ...
     void clear();
 
@@ -190,6 +190,8 @@ class QgsWMSSourceSelect : public QgsAbstractDataSourceWidget, private Ui::QgsWM
     // save the current status of the layer true
     QMap<QTreeWidgetItem *, bool> mTreeInitialExpand = QMap<QTreeWidgetItem *, bool>();
 
+    QgsWmsInterpretationComboBox *mInterpretationCombo = nullptr;
+
   private slots:
     void lstTilesets_itemClicked( QTableWidgetItem *item );
     void mLayerUpButton_clicked();
@@ -198,5 +200,23 @@ class QgsWMSSourceSelect : public QgsAbstractDataSourceWidget, private Ui::QgsWM
     void showHelp();
 };
 
+/*!
+ * \brief ComboBox to select interpretation to convert image to a single band raster
+ */
+class QgsWmsInterpretationComboBox : public QComboBox
+{
+    Q_OBJECT
+  public:
+    //! Constructor
+    QgsWmsInterpretationComboBox( QWidget *parent = nullptr );
+
+    /**
+     * Sets the interpretation from its key \a interpretationKey, default if interpretationKey is empty
+     */
+    void setInterpretation( const QString &interpretationKey );
+
+    //! Returns the key of the current selected interpretation, returns empty string if the current is default
+    QString interpretation() const;
+};
 
 #endif // QGSWMSSOURCESELECT_H
