@@ -20,6 +20,7 @@
 #include "qgspoint.h"
 #include "qgslinestring.h"
 #include "qgsvectorlayer.h"
+#include "qgsvectorlayerfeatureiterator.h"
 #include <QEventLoop>
 #include <QObject>
 #include <QTemporaryFile>
@@ -39,14 +40,14 @@ class TestQgsConnectionPool: public QObject
   private:
     struct ReadJob
     {
-      explicit ReadJob( QgsVectorLayer *_layer ) : layer( _layer ) {}
-      QgsVectorLayer *layer = nullptr;
+      explicit ReadJob( QgsVectorLayer *_layer ) : source( std::make_shared< QgsVectorLayerFeatureSource >( _layer ) ) {}
+      std::shared_ptr< QgsVectorLayerFeatureSource> source;
       QList<QgsFeature> features;
     };
 
     static void processJob( ReadJob &job )
     {
-      QgsFeatureIterator it = job.layer->getFeatures();
+      QgsFeatureIterator it = job.source->getFeatures();
       QgsFeature f;
       while ( it.nextFeature( f ) )
       {
