@@ -22,16 +22,17 @@
 #include "qgsproject.h"
 #include "qgsvectorlayer.h"
 #include "qgsfontutils.h"
+#include "qgsmaplayerstyle.h"
 #include "qgsnullsymbolrenderer.h"
-#include "qgstextrenderer.h"
 #include "qgspallabeling.h"
-#include "qgslabelingengine.h"
 #include "qgssinglesymbolrenderer.h"
 #include "qgsvectorlayerlabeling.h"
 #include "qgslinesymbollayer.h"
 #include "qgsfillsymbol.h"
 #include "qgsmarkersymbol.h"
+#include "qgsmarkersymbollayer.h"
 #include "qgslinesymbol.h"
+
 #include <QTemporaryFile>
 #include <QRegularExpression>
 
@@ -50,9 +51,11 @@ class TestQgsDxfExport : public QObject
     void init();// will be called before each testfunction is executed.
     void cleanup();// will be called after every testfunction.
     void testPoints();
+    void testPointsDataDefinedSizeAngle();
     void testLines();
     void testPolygons();
     void testMultiSurface();
+    void testMapTheme();
     void testMtext();
     void testMtext_data();
     void testMTextEscapeSpaces();
@@ -68,11 +71,13 @@ class TestQgsDxfExport : public QObject
     void testCurveExport_data();
     void testDashedLine();
     void testTransform();
+    void testDataDefinedPoints();
 
   private:
     QgsVectorLayer *mPointLayer = nullptr;
     QgsVectorLayer *mPointLayerNoSymbols = nullptr;
     QgsVectorLayer *mPointLayerGeometryGenerator = nullptr;
+    QgsVectorLayer *mPointLayerDataDefinedSizeAngle = nullptr;
     QgsVectorLayer *mLineLayer = nullptr;
     QgsVectorLayer *mPolygonLayer = nullptr;
 
@@ -128,6 +133,21 @@ void TestQgsDxfExport::init()
 
   QgsProject::instance()->addMapLayer( mPointLayerGeometryGenerator );
 
+  // Point layer with data-defined size and angle
+  mPointLayerDataDefinedSizeAngle = new  QgsVectorLayer( filename, QStringLiteral( "points" ), QStringLiteral( "ogr" ) );
+  mPointLayerDataDefinedSizeAngle->setSubsetString( QStringLiteral( "\"Staff\" = 6" ) );
+  QVERIFY( mPointLayerDataDefinedSizeAngle );
+  QgsSimpleMarkerSymbolLayer *markerSymbolLayer = new QgsSimpleMarkerSymbolLayer( Qgis::MarkerShape::Triangle, 10.0, 0 );
+  QgsPropertyCollection properties;
+  properties.setProperty( QgsSymbolLayer::PropertySize, QgsProperty::fromExpression( "coalesce( 10 + $id * 5, 10 )" ) );
+  properties.setProperty( QgsSymbolLayer::PropertyAngle, QgsProperty::fromExpression( "coalesce( $id * 5, 0 )" ) );
+  markerSymbolLayer->setDataDefinedProperties( properties );
+  QgsSymbolLayerList symbolLayerList;
+  symbolLayerList << markerSymbolLayer;
+  QgsMarkerSymbol *markerDataDefinedSymbol = new QgsMarkerSymbol( symbolLayerList );
+  mPointLayerDataDefinedSizeAngle->setRenderer( new QgsSingleSymbolRenderer( markerDataDefinedSymbol ) );
+  QgsProject::instance()->addMapLayer( mPointLayerDataDefinedSizeAngle );
+
   filename = QStringLiteral( TEST_DATA_DIR ) + "/lines.shp";
   mLineLayer = new QgsVectorLayer( filename, QStringLiteral( "lines" ), QStringLiteral( "ogr" ) );
   QVERIFY( mLineLayer->isValid() );
@@ -175,7 +195,33 @@ void TestQgsDxfExport::testPoints()
   std::unique_ptr< QgsVectorLayer > result = std::make_unique< QgsVectorLayer >( file, "dxf" );
   QVERIFY( result->isValid() );
   QCOMPARE( result->featureCount(), mPointLayer->featureCount() );
-  QCOMPARE( result->wkbType(), QgsWkbTypes::Point );
+  QCOMPARE( result->wkbType(), Qgis::WkbType::Point );
+}
+
+void TestQgsDxfExport::testPointsDataDefinedSizeAngle()
+{
+  QgsDxfExport d;
+  d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( mPointLayerDataDefinedSizeAngle ) );
+
+  QgsMapSettings mapSettings;
+  const QSize size( 640, 480 );
+  mapSettings.setOutputSize( size );
+  mapSettings.setExtent( mPointLayerDataDefinedSizeAngle->extent() );
+  mapSettings.setLayers( QList<QgsMapLayer *>() << mPointLayerDataDefinedSizeAngle );
+  mapSettings.setOutputDpi( 96 );
+  mapSettings.setDestinationCrs( mPointLayerDataDefinedSizeAngle->crs() );
+
+  d.setMapSettings( mapSettings );
+  d.setSymbologyScale( 2000000 );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
+
+  const QString file = getTempFileName( "point_datadefined_size_angle" );
+  QFile dxfFile( file );
+  QCOMPARE( d.writeToFile( &dxfFile, QStringLiteral( "CP1252" ) ), QgsDxfExport::ExportResult::Success );
+  dxfFile.close();
+
+  // Verify that blocks have been used even though size and angle were data defined properties
+  QVERIFY( fileContainsText( file, QStringLiteral( "symbolLayer0" ) ) );
 }
 
 void TestQgsDxfExport::testLines()
@@ -203,7 +249,7 @@ void TestQgsDxfExport::testLines()
   std::unique_ptr< QgsVectorLayer > result = std::make_unique< QgsVectorLayer >( file, "dxf" );
   QVERIFY( result->isValid() );
   QCOMPARE( result->featureCount(), mLineLayer->featureCount() );
-  QCOMPARE( result->wkbType(), QgsWkbTypes::LineString );
+  QCOMPARE( result->wkbType(), Qgis::WkbType::LineString );
 }
 
 void TestQgsDxfExport::testPolygons()
@@ -231,7 +277,7 @@ void TestQgsDxfExport::testPolygons()
   std::unique_ptr< QgsVectorLayer > result = std::make_unique< QgsVectorLayer >( file, "dxf" );
   QVERIFY( result->isValid() );
   QCOMPARE( result->featureCount(), 12L );
-  QCOMPARE( result->wkbType(), QgsWkbTypes::LineString );
+  QCOMPARE( result->wkbType(), Qgis::WkbType::LineString );
 }
 
 void TestQgsDxfExport::testMultiSurface()
@@ -264,12 +310,65 @@ void TestQgsDxfExport::testMultiSurface()
   std::unique_ptr< QgsVectorLayer > result = std::make_unique< QgsVectorLayer >( file, "dxf" );
   QVERIFY( result->isValid() );
   QCOMPARE( result->featureCount(), 1L );
-  QCOMPARE( result->wkbType(), QgsWkbTypes::LineString );
+  QCOMPARE( result->wkbType(), Qgis::WkbType::LineString );
   QgsFeature f2;
   result->getFeatures().nextFeature( f2 );
   QCOMPARE( f2.geometry().asWkt(), QStringLiteral( "LineString (0 0, 0 1, 1 1, 0 0)" ) );
 }
 
+void TestQgsDxfExport::testMapTheme()
+{
+  std::unique_ptr< QgsVectorLayer > vl = std::make_unique< QgsVectorLayer >( QStringLiteral( "LineString?crs=epsg:2056" ), QString(), QStringLiteral( "memory" ) );
+  const QgsGeometry g = QgsGeometry::fromWkt( "LineString(2600000 1280000, 2680000 1280000, 2680000 1285000, 2600000 1285000, 2600000 1280000)" );
+  QgsFeature f;
+  f.setGeometry( g );
+  vl->dataProvider()->addFeatures( QgsFeatureList() << f );
+
+  std::unique_ptr<QgsSimpleLineSymbolLayer> symbolLayer = std::make_unique<QgsSimpleLineSymbolLayer>( QColor( 0, 255, 0 ) );
+  symbolLayer->setWidth( 0.11 );
+  QgsLineSymbol *symbol = new QgsLineSymbol();
+  symbol->changeSymbolLayer( 0, symbolLayer.release() );
+
+  QgsSingleSymbolRenderer *renderer = new QgsSingleSymbolRenderer( symbol );
+  vl->setRenderer( renderer );
+
+  // Save layer style with green line
+  QMap<QString, QString> styleOverrides;
+  QgsMapLayerStyle layerStyle;
+  layerStyle.readFromLayer( vl.get() );
+  styleOverrides[vl->id()] = layerStyle.xmlData();
+
+  // Change layer style to red line
+  dynamic_cast<QgsSingleSymbolRenderer *>( vl->renderer() )->symbol()->setColor( QColor( 255, 0, 0 ) );
+
+  QgsDxfExport d;
+  d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( vl.get() ) );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerSymbolLayer );
+
+  QgsMapSettings mapSettings;
+  const QSize size( 640, 480 );
+  mapSettings.setOutputSize( size );
+  mapSettings.setExtent( vl->extent() );
+  mapSettings.setLayers( QList<QgsMapLayer *>() << vl.get() );
+  mapSettings.setOutputDpi( 96 );
+  mapSettings.setDestinationCrs( vl->crs() );
+  mapSettings.setLayerStyleOverrides( styleOverrides );
+
+  d.setMapSettings( mapSettings );
+  d.setSymbologyScale( 1000 );
+
+  const QString file = getTempFileName( "map_theme_dxf" );
+  QFile dxfFile( file );
+  QCOMPARE( d.writeToFile( &dxfFile, QStringLiteral( "CP1252" ) ), QgsDxfExport::ExportResult::Success );
+  dxfFile.close();
+
+  QString debugInfo;
+  // Verify that the style override worked by checking for green line color
+  QVERIFY2( fileContainsText( file, "CONTINUOUS\n"
+                              " 62\n"
+                              "     3", &debugInfo ), debugInfo.toUtf8().constData() );
+}
+
 void TestQgsDxfExport::testMtext()
 {
   QFETCH( QgsVectorLayer *, layer );
@@ -303,7 +402,7 @@ void TestQgsDxfExport::testMtext()
 
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
 
   const QString file = getTempFileName( layerName );
   QFile dxfFile( file );
@@ -392,7 +491,7 @@ void TestQgsDxfExport::testMTextEscapeSpaces()
 
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
 
   const QString file = getTempFileName( "mtext_escape_spaces" );
   QFile dxfFile( file );
@@ -430,7 +529,7 @@ void TestQgsDxfExport::testMTextEscapeLineBreaks()
 
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
 
   const QString file = getTempFileName( "mtext_escape_linebreaks" );
   QFile dxfFile( file );
@@ -470,7 +569,7 @@ void TestQgsDxfExport::testText()
 
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
   d.setFlags( QgsDxfExport::FlagNoMText );
 
   const QString file = getTempFileName( "text_dxf" );
@@ -549,7 +648,7 @@ void TestQgsDxfExport::testTextAngle()
 
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
   d.setFlags( QgsDxfExport::FlagNoMText );
 
   const QString file = getTempFileName( "text_dxf_angle" );
@@ -639,12 +738,10 @@ void TestQgsDxfExport::testTextAlign()
   d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( vl.get() ) );
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
   d.setFlags( QgsDxfExport::FlagNoMText );
   d.setExtent( mapSettings.extent() );
 
-  static int testNumber = 0;
-  ++testNumber;
   const QString file = getTempFileName( QStringLiteral( "text_dxf_%1_%2" ).arg( hali, vali ) );
   QFile dxfFile( file );
   QCOMPARE( d.writeToFile( &dxfFile, QStringLiteral( "CP1252" ) ), QgsDxfExport::ExportResult::Success );
@@ -782,12 +879,10 @@ void TestQgsDxfExport::testTextQuadrant()
   d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( vl.get() ) );
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 1000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
   d.setFlags( QgsDxfExport::FlagNoMText );
   d.setExtent( mapSettings.extent() );
 
-  static int testNumber = 0;
-  ++testNumber;
   const QString file = getTempFileName( QStringLiteral( "text_dxf_offset_quad_%1_%2" ).arg( offsetQuad ).arg( angle ) );
   QFile dxfFile( file );
   QCOMPARE( d.writeToFile( &dxfFile, QStringLiteral( "CP1252" ) ), QgsDxfExport::ExportResult::Success );
@@ -911,7 +1006,7 @@ void TestQgsDxfExport::testGeometryGeneratorExport()
 
   d.setMapSettings( mapSettings );
   d.setSymbologyScale( 6000000 );
-  d.setSymbologyExport( QgsDxfExport::FeatureSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
 
   const QString file = getTempFileName( "geometry_generator_dxf" );
   QFile dxfFile( file );
@@ -1060,7 +1155,7 @@ void TestQgsDxfExport::testDashedLine()
   std::unique_ptr<QgsSimpleLineSymbolLayer> symbolLayer = std::make_unique<QgsSimpleLineSymbolLayer>( QColor( 0, 0, 0 ) );
   symbolLayer->setWidth( 0.11 );
   symbolLayer->setCustomDashVector( { 0.5, 0.35 } );
-  symbolLayer->setCustomDashPatternUnit( QgsUnitTypes::RenderUnit::RenderMapUnits );
+  symbolLayer->setCustomDashPatternUnit( Qgis::RenderUnit::MapUnits );
   symbolLayer->setUseCustomDashPattern( true );
 
   QgsLineSymbol *symbol = new QgsLineSymbol();
@@ -1076,7 +1171,7 @@ void TestQgsDxfExport::testDashedLine()
 
   QgsDxfExport d;
   d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( vl.get() ) );
-  d.setSymbologyExport( QgsDxfExport::SymbologyExport::SymbolLayerSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerSymbolLayer );
 
   QgsMapSettings mapSettings;
   const QSize size( 640, 480 );
@@ -1181,7 +1276,7 @@ void TestQgsDxfExport::testTransform()
   std::unique_ptr<QgsSimpleLineSymbolLayer> symbolLayer = std::make_unique<QgsSimpleLineSymbolLayer>( QColor( 0, 0, 0 ) );
   symbolLayer->setWidth( 0.11 );
   symbolLayer->setCustomDashVector( { 0.5, 0.35 } );
-  symbolLayer->setCustomDashPatternUnit( QgsUnitTypes::RenderUnit::RenderMapUnits );
+  symbolLayer->setCustomDashPatternUnit( Qgis::RenderUnit::MapUnits );
   symbolLayer->setUseCustomDashPattern( true );
 
   QgsLineSymbol *symbol = new QgsLineSymbol();
@@ -1201,7 +1296,7 @@ void TestQgsDxfExport::testTransform()
 
   QgsDxfExport d;
   d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( vl.get() ) );
-  d.setSymbologyExport( QgsDxfExport::SymbologyExport::SymbolLayerSymbology );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerSymbolLayer );
 
   QgsMapSettings mapSettings;
   const QSize size( 640, 480 );
@@ -1243,6 +1338,76 @@ void TestQgsDxfExport::testTransform()
   QCOMPARE( f2.geometry().asWkt( 0 ), QStringLiteral( "LineString (960862 6056454, 960915 6056455)" ) );
 }
 
+void TestQgsDxfExport::testDataDefinedPoints()
+{
+  std::unique_ptr<QgsSimpleMarkerSymbolLayer> symbolLayer = std::make_unique<QgsSimpleMarkerSymbolLayer>( Qgis::MarkerShape::Circle, 2.0 );
+  QgsPropertyCollection properties;
+  properties.setProperty( QgsSymbolLayer::PropertySize, QgsProperty::fromExpression( "200" ) );
+  symbolLayer->setDataDefinedProperties( properties );
+
+  QgsMarkerSymbol *symbol = new QgsMarkerSymbol();
+  symbol->changeSymbolLayer( 0, symbolLayer.release() );
+
+  std::unique_ptr< QgsVectorLayer > vl = std::make_unique< QgsVectorLayer >( QStringLiteral( "Point?crs=epsg:2056" ), QString(), QStringLiteral( "memory" ) );
+  const QgsGeometry g1 = QgsGeometry::fromWkt( "POINT (2000000 1000000)" );
+  QgsFeature f1;
+  f1.setGeometry( g1 );
+  const QgsGeometry g2 = QgsGeometry::fromWkt( "POINT (2000100 1000100)" );
+  QgsFeature f2;
+  f2.setGeometry( g2 );
+  vl->dataProvider()->addFeatures( QgsFeatureList() << f1 << f2 );
+
+  QgsSingleSymbolRenderer *renderer = new QgsSingleSymbolRenderer( symbol );
+  vl->setRenderer( renderer );
+
+  QgsDxfExport d;
+  d.addLayers( QList< QgsDxfExport::DxfLayer >() << QgsDxfExport::DxfLayer( vl.get() ) );
+  d.setSymbologyExport( Qgis::FeatureSymbologyExport::PerFeature );
+
+  QgsMapSettings mapSettings;
+  const QSize size( 640, 480 );
+  mapSettings.setOutputSize( size );
+  mapSettings.setExtent( vl->extent().buffered( 100.0 ) );
+  mapSettings.setLayers( QList<QgsMapLayer *>() << vl.get() );
+  mapSettings.setOutputDpi( 96 );
+  mapSettings.setDestinationCrs( vl->crs() );
+
+  d.setMapSettings( mapSettings );
+  d.setSymbologyScale( 1000 );
+
+  const QString file = getTempFileName( "data_defined_points_dxf" );
+  QFile dxfFile( file );
+  QCOMPARE( d.writeToFile( &dxfFile, QStringLiteral( "CP1252" ) ), QgsDxfExport::ExportResult::Success );
+  dxfFile.close();
+
+  QString debugInfo;
+
+  QVERIFY2( fileContainsText( file,
+                              "CONTINUOUS\n"
+                              "420\n"
+                              "2302755\n"
+                              " 90\n"
+                              "     2\n"
+                              " 70\n"
+                              "     1\n"
+                              " 43\n"
+                              "0.0\n"
+                              " 10\n"
+                              "-100.0\n"
+                              " 20\n"
+                              "0.0\n"
+                              " 42\n"
+                              "1.0\n"
+                              " 10\n"
+                              "100.0\n"
+                              " 20\n"
+                              "0.0\n"
+                              " 42\n"
+                              "1.0\n"
+                              "  0\n"
+                              "ENDBLK", &debugInfo ), debugInfo.toUtf8().constData() );
+}
+
 bool TestQgsDxfExport::fileContainsText( const QString &path, const QString &text, QString *debugInfo ) const
 {
   QStringList debugLines;
