@@ -11,14 +11,16 @@ __copyright__ = 'Copyright 2021, QGIS Project'
 
 import qgis  # NOQA
 
-from qgis.core import (QgsVectorLayer,
-                       QgsFeature,
-                       QgsPolymorphicRelation,
-                       QgsGeometry,
-                       QgsPointXY,
-                       QgsProject
-                       )
-from qgis.testing import start_app, unittest
+from qgis.core import (
+    QgsFeature,
+    QgsGeometry,
+    QgsPointXY,
+    QgsPolymorphicRelation,
+    QgsProject,
+    QgsVectorLayer,
+)
+import unittest
+from qgis.testing import start_app, QgisTestCase
 
 start_app()
 
@@ -68,7 +70,7 @@ def formatAttributes(attrs):
     return repr([str(a) for a in attrs])
 
 
-class TestQgsRelation(unittest.TestCase):
+class TestQgsRelation(QgisTestCase):
 
     def setUp(self):
         self.referencedLayer1 = createReferencedLayer('referencedlayer1')
