@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """QGIS Unit tests for edit widgets.
 
 .. note:: This program is free software; you can redistribute it and/or modify
@@ -10,43 +9,41 @@ __author__ = 'Matthias Kuhn'
 __date__ = '28/11/2015'
 __copyright__ = 'Copyright 2015, The QGIS Project'
 
-import qgis  # NOQA
-
 import os
 
+import qgis  # NOQA
+from qgis.PyQt.QtCore import QTimer
+from qgis.PyQt.QtWidgets import (
+    QDialog,
+    QDialogButtonBox,
+    QMessageBox,
+    QTableView,
+    QToolButton,
+)
 from qgis.core import (
     QgsFeature,
-    QgsVectorLayer,
+    QgsFeatureRequest,
+    QgsGeometry,
     QgsProject,
     QgsRelation,
     QgsTransaction,
-    QgsFeatureRequest,
+    QgsVectorLayer,
     QgsVectorLayerTools,
-    QgsGeometry
 )
-
 from qgis.gui import (
-    QgsGui,
-    QgsRelationWidgetWrapper,
+    QgsAdvancedDigitizingDockWidget,
     QgsAttributeEditorContext,
+    QgsGui,
     QgsMapCanvas,
-    QgsAdvancedDigitizingDockWidget
+    QgsRelationWidgetWrapper,
 )
-
-from qgis.PyQt.QtCore import QTimer
-from qgis.PyQt.QtWidgets import (
-    QToolButton,
-    QMessageBox,
-    QDialogButtonBox,
-    QTableView,
-    QDialog
-)
-from qgis.testing import start_app, unittest
+import unittest
+from qgis.testing import start_app, QgisTestCase
 
 start_app()
 
 
-class TestQgsRelationEditWidget(unittest.TestCase):
+class TestQgsRelationEditWidget(QgisTestCase):
 
     @classmethod
     def setUpClass(cls):
@@ -54,6 +51,7 @@ class TestQgsRelationEditWidget(unittest.TestCase):
         Setup the involved layers and relations for a n:m relation
         :return:
         """
+        super().setUpClass()
         cls.mapCanvas = QgsMapCanvas()
         QgsGui.editorWidgetRegistry().initEditors(cls.mapCanvas)
         cls.dbconn = 'service=\'qgis_test\''
@@ -93,6 +91,8 @@ class TestQgsRelationEditWidget(unittest.TestCase):
         cls.vltools = None
         cls.relMgr = None
 
+        super().tearDownClass()
+
     def setUp(self):
         self.rel_a = QgsRelation()
         self.rel_a.setReferencingLayer(self.vl_link_books_authors.id())
@@ -161,7 +161,7 @@ class TestQgsRelationEditWidget(unittest.TestCase):
             # box
             widget = self.widget.findChild(QMessageBox)
             buttonBox = widget.findChild(QDialogButtonBox)
-            deleteButton = next((b for b in buttonBox.buttons() if buttonBox.buttonRole(b) == QDialogButtonBox.AcceptRole))
+            deleteButton = next(b for b in buttonBox.buttons() if buttonBox.buttonRole(b) == QDialogButtonBox.AcceptRole)
             deleteButton.click()
 
         QTimer.singleShot(1, clickOk)
@@ -221,7 +221,7 @@ class TestQgsRelationEditWidget(unittest.TestCase):
         dlg.accept()
 
         # magically the above code selects the feature here...
-        link_feature = next(self.vl_link_books_authors.getFeatures(QgsFeatureRequest().setFilterExpression('"fk_book"={}'.format(f[0]))))
+        link_feature = next(self.vl_link_books_authors.getFeatures(QgsFeatureRequest().setFilterExpression(f'"fk_book"={f[0]}')))
         self.assertIsNotNone(link_feature[0])
 
         self.assertEqual(self.table_view.model().rowCount(), 1)
@@ -342,7 +342,7 @@ class TestQgsRelationEditWidget(unittest.TestCase):
         # Mock vector layer tool to just set default value on created feature
         class DummyVlTools(QgsVectorLayerTools):
 
-            def addFeature(self, layer, defaultValues, defaultGeometry):
+            def addFeature(self, layer, defaultValues, defaultGeometry, parentWidget=None, showModal=True, hideParent=False):
                 f = QgsFeature(layer.fields())
                 for idx, value in defaultValues.items():
                     f.setAttribute(idx, value)
@@ -441,7 +441,7 @@ class VlTools(QgsVectorLayerTools):
         """
         self.values = values
 
-    def addFeature(self, layer, defaultValues, defaultGeometry):
+    def addFeature(self, layer, defaultValues, defaultGeometry, parentWidget=None, showModal=True, hideParent=False):
         """
         Overrides the addFeature method
         :param layer: vector layer
