@@ -12,7 +12,7 @@ __author__ = 'Alessandro Pasotti'
 __date__ = '11/07/2019'
 __copyright__ = 'Copyright 2019, The QGIS Project'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '252ad49ddcbc4a0dcfe9eb9381503de0fde9e0ed'
+__revision__ = '623828f58c27651d637d70026e9145f682358bbd'
 
 import os
 
@@ -22,10 +22,9 @@ os.environ['QT_HASH_SEED'] = '1'
 from qgis.server import (
     QgsBufferServerRequest,
     QgsBufferServerResponse,
-    QgsServerApiContext
+    QgsServerApiContext,
 )
 from qgis.testing import unittest
-
 from test_qgsserver import QgsServerTestBase
 
 
