@@ -12,17 +12,19 @@ __copyright__ = 'Copyright 2021, The QGIS Project'
 import os
 
 import qgis  # NOQA
-from qgis.core import (QgsVectorLayer,
-                       QgsVectorLayerUtils,
-                       QgsDefaultValue,
-                       NULL
-                       )
-from qgis.testing import start_app, unittest
+from qgis.core import (
+    NULL,
+    QgsDefaultValue,
+    QgsVectorLayer,
+    QgsVectorLayerUtils,
+)
+import unittest
+from qgis.testing import start_app, QgisTestCase
 
 start_app()
 
 
-class TestQgsVectorLayerUtilsPostgres(unittest.TestCase):
+class TestQgsVectorLayerUtilsPostgres(QgisTestCase):
 
     def testCreateFeature(self):
         """ test creating a feature respecting unique values of postgres provider """
